@@ -1,10 +1,11 @@
-__version__ = "1.1.0"
+import time
+
+__version__ = "2.0.1"
 "Module version string."
 
-version = (1,1,0)
+version = (2, 0, 1)
 "Module version tuple."
 
-import time
 
 def sleep(seconds):
     """Sleep for the specified number of seconds.
@@ -15,6 +16,7 @@ def sleep(seconds):
     """
     time.sleep(seconds)
 
+
 def sleep_ms(milliseconds):
     """Sleep for the specified number of milliseconds.
 
@@ -24,6 +26,7 @@ def sleep_ms(milliseconds):
     """
     time.sleep(milliseconds / 1000.0)
 
+
 def sleep_us(microseconds):
     """Sleep for the specified number of microseconds.
 
@@ -33,11 +36,11 @@ def sleep_us(microseconds):
     """
     time.sleep(microseconds / 1000000.0)
 
-from periphery.gpio import GPIO, GPIOError
+
+from periphery.gpio import GPIO, SysfsGPIO, CdevGPIO, EdgeEvent, GPIOError
 from periphery.led import LED, LEDError
 from periphery.pwm import PWM, PWMError
 from periphery.spi import SPI, SPIError
 from periphery.i2c import I2C, I2CError
 from periphery.mmio import MMIO, MMIOError
 from periphery.serial import Serial, SerialError
-
