@@ -3,10 +3,12 @@ import fcntl
 import array
 import ctypes
 
+
 class SPIError(IOError):
     """Base class for SPI errors."""
     pass
 
+
 class _CSpiIocTransfer(ctypes.Structure):
     _fields_ = [
         ('tx_buf', ctypes.c_ulonglong),
@@ -21,18 +23,19 @@ class _CSpiIocTransfer(ctypes.Structure):
         ('pad', ctypes.c_ushort),
     ]
 
+
 class SPI(object):
     # Constants scraped from <linux/spi/spidev.h>
-    _SPI_CPHA        = 0x1
-    _SPI_CPOL        = 0x2
-    _SPI_LSB_FIRST   = 0x8
-    _SPI_IOC_WR_MODE            = 0x40016b01
-    _SPI_IOC_RD_MODE            = 0x80016b01
-    _SPI_IOC_WR_MAX_SPEED_HZ    = 0x40046b04
-    _SPI_IOC_RD_MAX_SPEED_HZ    = 0x80046b04
-    _SPI_IOC_WR_BITS_PER_WORD   = 0x40016b03
-    _SPI_IOC_RD_BITS_PER_WORD   = 0x80016b03
-    _SPI_IOC_MESSAGE_1          = 0x40206b00
+    _SPI_CPHA = 0x1
+    _SPI_CPOL = 0x2
+    _SPI_LSB_FIRST = 0x8
+    _SPI_IOC_WR_MODE = 0x40016b01
+    _SPI_IOC_RD_MODE = 0x80016b01
+    _SPI_IOC_WR_MAX_SPEED_HZ = 0x40046b04
+    _SPI_IOC_RD_MAX_SPEED_HZ = 0x80046b04
+    _SPI_IOC_WR_BITS_PER_WORD = 0x40016b03
+    _SPI_IOC_RD_BITS_PER_WORD = 0x80016b03
+    _SPI_IOC_MESSAGE_1 = 0x40206b00
 
     def __init__(self, devpath, mode, max_speed, bit_order="msb", bits_per_word=8, extra_flags=0):
         """Instantiate a SPI object and open the spidev device at the specified
@@ -64,7 +67,7 @@ class SPI(object):
         self.close()
 
     def __enter__(self):
-        pass
+        return self
 
     def __exit__(self, t, value, traceback):
         self.close()
@@ -106,21 +109,21 @@ class SPI(object):
         buf = array.array("B", [mode | (SPI._SPI_LSB_FIRST if bit_order == "lsb" else 0) | extra_flags])
         try:
             fcntl.ioctl(self._fd, SPI._SPI_IOC_WR_MODE, buf, False)
-        except OSError as e:
+        except (OSError, IOError) as e:
             raise SPIError(e.errno, "Setting SPI mode: " + e.strerror)
 
         # Set max speed
         buf = array.array("I", [int(max_speed)])
         try:
             fcntl.ioctl(self._fd, SPI._SPI_IOC_WR_MAX_SPEED_HZ, buf, False)
-        except OSError as e:
+        except (OSError, IOError) as e:
             raise SPIError(e.errno, "Setting SPI max speed: " + e.strerror)
 
         # Set bits per word
         buf = array.array("B", [bits_per_word])
         try:
             fcntl.ioctl(self._fd, SPI._SPI_IOC_WR_BITS_PER_WORD, buf, False)
-        except OSError as e:
+        except (OSError, IOError) as e:
             raise SPIError(e.errno, "Setting SPI bits per word: " + e.strerror)
 
     # Methods
@@ -160,7 +163,7 @@ class SPI(object):
         # Transfer
         try:
             fcntl.ioctl(self._fd, SPI._SPI_IOC_MESSAGE_1, spi_xfer)
-        except OSError as e:
+        except (OSError, IOError) as e:
             raise SPIError(e.errno, "SPI transfer: " + e.strerror)
 
         # Return shifted out data with the same type as shifted in data
@@ -214,7 +217,7 @@ class SPI(object):
         # Get mode
         try:
             fcntl.ioctl(self._fd, SPI._SPI_IOC_RD_MODE, buf, True)
-        except OSError as e:
+        except (OSError, IOError) as e:
             raise SPIError(e.errno, "Getting SPI mode: " + e.strerror)
 
         return buf[0] & 0x3
@@ -231,7 +234,7 @@ class SPI(object):
         buf = array.array('B', [0])
         try:
             fcntl.ioctl(self._fd, SPI._SPI_IOC_RD_MODE, buf, True)
-        except OSError as e:
+        except (OSError, IOError) as e:
             raise SPIError(e.errno, "Getting SPI mode: " + e.strerror)
 
         buf[0] = (buf[0] & ~(SPI._SPI_CPOL | SPI._SPI_CPHA)) | mode
@@ -239,7 +242,7 @@ class SPI(object):
         # Set mode
         try:
             fcntl.ioctl(self._fd, SPI._SPI_IOC_WR_MODE, buf, False)
-        except OSError as e:
+        except (OSError, IOError) as e:
             raise SPIError(e.errno, "Setting SPI mode: " + e.strerror)
 
     mode = property(_get_mode, _set_mode)
@@ -258,7 +261,7 @@ class SPI(object):
         buf = array.array('I', [0])
         try:
             fcntl.ioctl(self._fd, SPI._SPI_IOC_RD_MAX_SPEED_HZ, buf, True)
-        except OSError as e:
+        except (OSError, IOError) as e:
             raise SPIError(e.errno, "Getting SPI max speed: " + e.strerror)
 
         return buf[0]
@@ -271,7 +274,7 @@ class SPI(object):
         buf = array.array('I', [int(max_speed)])
         try:
             fcntl.ioctl(self._fd, SPI._SPI_IOC_WR_MAX_SPEED_HZ, buf, False)
-        except OSError as e:
+        except (OSError, IOError) as e:
             raise SPIError(e.errno, "Setting SPI max speed: " + e.strerror)
 
     max_speed = property(_get_max_speed, _set_max_speed)
@@ -289,7 +292,7 @@ class SPI(object):
         buf = array.array('B', [0])
         try:
             fcntl.ioctl(self._fd, SPI._SPI_IOC_RD_MODE, buf, True)
-        except OSError as e:
+        except (OSError, IOError) as e:
             raise SPIError(e.errno, "Getting SPI mode: " + e.strerror)
 
         if (buf[0] & SPI._SPI_LSB_FIRST) > 0:
@@ -309,7 +312,7 @@ class SPI(object):
         buf = array.array('B', [0])
         try:
             fcntl.ioctl(self._fd, SPI._SPI_IOC_RD_MODE, buf, True)
-        except OSError as e:
+        except (OSError, IOError) as e:
             raise SPIError(e.errno, "Getting SPI mode: " + e.strerror)
 
         bit_order = bit_order.lower()
@@ -318,7 +321,7 @@ class SPI(object):
         # Set mode
         try:
             fcntl.ioctl(self._fd, SPI._SPI_IOC_WR_MODE, buf, False)
-        except OSError as e:
+        except (OSError, IOError) as e:
             raise SPIError(e.errno, "Setting SPI mode: " + e.strerror)
 
     bit_order = property(_get_bit_order, _set_bit_order)
@@ -337,7 +340,7 @@ class SPI(object):
         buf = array.array('B', [0])
         try:
             fcntl.ioctl(self._fd, SPI._SPI_IOC_RD_BITS_PER_WORD, buf, True)
-        except OSError as e:
+        except (OSError, IOError) as e:
             raise SPIError(e.errno, "Getting SPI bits per word: " + e.strerror)
 
         return buf[0]
@@ -352,7 +355,7 @@ class SPI(object):
         buf = array.array('B', [bits_per_word])
         try:
             fcntl.ioctl(self._fd, SPI._SPI_IOC_WR_BITS_PER_WORD, buf, False)
-        except OSError as e:
+        except (OSError, IOError) as e:
             raise SPIError(e.errno, "Setting SPI bits per word: " + e.strerror)
 
     bits_per_word = property(_get_bits_per_word, _set_bits_per_word)
@@ -371,7 +374,7 @@ class SPI(object):
         buf = array.array('B', [0])
         try:
             fcntl.ioctl(self._fd, SPI._SPI_IOC_RD_MODE, buf, True)
-        except OSError as e:
+        except (OSError, IOError) as e:
             raise SPIError(e.errno, "Getting SPI mode: " + e.strerror)
 
         return buf[0] & ~(SPI._SPI_LSB_FIRST | SPI._SPI_CPHA | SPI._SPI_CPOL)
@@ -388,7 +391,7 @@ class SPI(object):
         buf = array.array('B', [0])
         try:
             fcntl.ioctl(self._fd, SPI._SPI_IOC_RD_MODE, buf, True)
-        except OSError as e:
+        except (OSError, IOError) as e:
             raise SPIError(e.errno, "Getting SPI mode: " + e.strerror)
 
         buf[0] = (buf[0] & (SPI._SPI_LSB_FIRST | SPI._SPI_CPHA | SPI._SPI_CPOL)) | extra_flags
@@ -396,7 +399,7 @@ class SPI(object):
         # Set mode
         try:
             fcntl.ioctl(self._fd, SPI._SPI_IOC_WR_MODE, buf, False)
-        except OSError as e:
+        except (OSError, IOError) as e:
             raise SPIError(e.errno, "Setting SPI mode: " + e.strerror)
 
     extra_flags = property(_get_extra_flags, _set_extra_flags)
@@ -413,5 +416,5 @@ class SPI(object):
     # String representation
 
     def __str__(self):
-        return "SPI (device=%s, fd=%d, mode=%s, max_speed=%d, bit_order=%s, bits_per_word=%d, extra_flags=0x%02x)" % (self.devpath, self.fd, self.mode, self.max_speed, self.bit_order, self.bits_per_word, self.extra_flags)
-
+        return "SPI (device={:s}, fd={:d}, mode={:d}, max_speed={:d}, bit_order={:s}, bits_per_word={:d}, extra_flags=0x{:02x})" \
+            .format(self.devpath, self.fd, self.mode, self.max_speed, self.bit_order, self.bits_per_word, self.extra_flags)
