@@ -3,7 +3,7 @@ class AssertRaises(object):
         self.exception_type = exception_type
 
     def __enter__(self):
-        pass
+        return self
 
     def __exit__(self, t, value, traceback):
         if isinstance(value, self.exception_type):
